
# Type: negatively regulates, process to process




URI: [biolink:negatively_regulates_process_to_process](https://w3id.org/biolink/vocab/negatively_regulates_process_to_process)


## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [regulates, process to process](regulates_process_to_process.md)

## Children


## Used by

 * [Occurrent](Occurrent.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002212 |

